KpostalView class

Inheritance

Constructors

KpostalView({Key? key, String title = '주소검색', Color appBarColor = Colors.white, Color titleColor = Colors.black, PreferredSizeWidget? appBar, dynamic callback(Kpostal result)?, bool useLocalServer = false, int localPort = 8080, Color loadingColor = Colors.blue, Widget? onLoading, String kakaoKey = ''})

Properties

appBar PreferredSizeWidget?
build custom AppBar.
final
appBarColor Color
AppBar's background color
final
callback → dynamic Function(Kpostal result)?
this callback function is called when user selects addresss.
final
hashCode int
The hash code for this object.
no setterinherited
kakaoKey String
kakaoKey 설정 시, kakaoLatitude, kakaoLongitude 값을 받을 수 있습니다.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingColor Color
웹뷰 로딩 시 인디케이터 색상
final
localPort int
Localhost port number. Default is 8080.
final
onLoading Widget?
웹뷰 로딩 시 표시할 커스텀 위젯
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
AppBar's title
final
titleColor Color
AppBar's contents color
final
useKakaoGeocoder bool
카카오 API를 통한 경위도 좌표 지오코딩 사용 여부
final
useLocalServer bool
if userLocalServer is true, the search page is running on localhost. Default is false.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _KpostalViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

routeName → const String